==> org.eclipse.rap.jface.databinding.source_3.13.0.20200318-1551.jar: org/eclipse/jface/internal/databinding/swt/WidgetEnabledProperty.java <==
/*******************************************************************************
 * Copyright (c) 2009 Matthew Hall and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Matthew Hall - initial API and implementation (bug 264286)
 *******************************************************************************/

package org.eclipse.jface.internal.databinding.swt;

import org.eclipse.core.databinding.property.value.IValueProperty;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.ScrollBar;
import org.eclipse.swt.widgets.ToolItem;

/**
 * @since 1.4
 */
public class WidgetEnabledProperty extends WidgetDelegatingValueProperty {
	IValueProperty control;
	IValueProperty menu;
	IValueProperty menuItem;
	IValueProperty scrollBar;
	IValueProperty toolItem;

	/**
	 * 
	 */
	public WidgetEnabledProperty() {
		super(Boolean.TYPE);
	}

	protected IValueProperty doGetDelegate(Object source) {
		if (source instanceof Control) {
			if (control == null)
				control = new ControlEnabledProperty();
			return control;
		}
		if (source instanceof Menu) {
			if (menu == null)
				menu = new MenuEnabledProperty();
			return menu;
		}
		if (source instanceof MenuItem) {
			if (menuItem == null)
				menuItem = new MenuItemEnabledProperty();
			return menuItem;
		}
		if (source instanceof ScrollBar) {
			if (scrollBar == null)
				scrollBar = new ScrollBarEnabledProperty();
			return scrollBar;
		}
		if (source instanceof ToolItem) {
			if (toolItem == null)
				toolItem = new ToolItemEnabledProperty();
			return toolItem;
		}
		throw notSupported(source);
	}
}

==> org.eclipse.rap.jface.databinding.source_4.0.0.20240621-0911.jar: org/eclipse/jface/internal/databinding/swt/WidgetEnabledProperty.java <==
/*******************************************************************************
 * Copyright (c) 2009 Matthew Hall and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Matthew Hall - initial API and implementation (bug 264286)
 *******************************************************************************/

package org.eclipse.jface.internal.databinding.swt;

import org.eclipse.core.databinding.property.value.IValueProperty;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.ScrollBar;
import org.eclipse.swt.widgets.ToolItem;
import org.eclipse.swt.widgets.Widget;

/**
 * @param <S> type of the source object
 * 
 * @since 1.4
 */
public class WidgetEnabledProperty<S extends Widget> extends WidgetDelegatingValueProperty<S, Boolean> {
	IValueProperty<Control, Boolean> control;
	IValueProperty<Menu, Boolean> menu;
	IValueProperty<MenuItem, Boolean> menuItem;
	IValueProperty<ScrollBar, Boolean> scrollBar;
	IValueProperty<ToolItem, Boolean> toolItem;

	/**
	 * 
	 */
	public WidgetEnabledProperty() {
		super(Boolean.TYPE);
	}

	@SuppressWarnings("unchecked")
	@Override
	protected IValueProperty<S, Boolean> doGetDelegate(S source) {
		if (source instanceof Control) {
			if (control == null)
				control = new ControlEnabledProperty();
			return (IValueProperty<S, Boolean>) control;
		}
		if (source instanceof Menu) {
			if (menu == null)
				menu = new MenuEnabledProperty();
			return (IValueProperty<S, Boolean>) menu;
		}
		if (source instanceof MenuItem) {
			if (menuItem == null)
				menuItem = new MenuItemEnabledProperty();
			return (IValueProperty<S, Boolean>) menuItem;
		}
		if (source instanceof ScrollBar) {
			if (scrollBar == null)
				scrollBar = new ScrollBarEnabledProperty();
			return (IValueProperty<S, Boolean>) scrollBar;
		}
		if (source instanceof ToolItem) {
			if (toolItem == null)
				toolItem = new ToolItemEnabledProperty();
			return (IValueProperty<S, Boolean>) toolItem;
		}
		throw notSupported(source);
	}
}
